@@ -10,6 +10,7 @@ use crate::axis::Axis;
 
 /// AABB struct.
 #[derive(Debug, Copy, Clone)]
+#[cfg_attr(feature = "serde_impls", derive(serde::Serialize, serde::Deserialize))]
 #[allow(clippy::upper_case_acronyms)]
 pub struct AABB {
     /// Minimum coordinates
@@ -654,15 +655,17 @@ impl Bounded for Point3 {
 #[cfg(test)]
 mod tests {
     use crate::aabb::{Bounded, AABB};
-    use crate::testbase::{tuple_to_point, tuple_to_vector, TupleVec};
+    use crate::testbase::{tuple_to_point, tuple_to_vector, tuplevec_large_strategy, TupleVec};
     use crate::EPSILON;
-
     use crate::{Point3, Vector3};
-    use quickcheck::quickcheck;
 
-    // Test whether an empty `AABB` does not contains anything.
-    quickcheck! {
-        fn test_empty_contains_nothing(tpl: TupleVec) -> bool {
+    use float_eq::assert_float_eq;
+    use proptest::prelude::*;
+
+    proptest! {
+        // Test whether an empty `AABB` does not contains anything.
+        #[test]
+        fn test_empty_contains_nothing(tpl: TupleVec) {
             // Define a random Point
             let p = tuple_to_point(&tpl);
 
@@ -670,13 +673,12 @@ mod tests {
             let aabb = AABB::empty();
 
             // It should not contain anything
-            !aabb.contains(&p)
+            assert!(!aabb.contains(&p));
         }
-    }
 
-    // Test whether a default `AABB` is empty.
-    quickcheck! {
-        fn test_default_is_empty(tpl: TupleVec) -> bool {
+        // Test whether a default `AABB` is empty.
+        #[test]
+        fn test_default_is_empty(tpl: TupleVec) {
             // Define a random Point
             let p = tuple_to_point(&tpl);
 
@@ -684,13 +686,12 @@ mod tests {
             let aabb: AABB = Default::default();
 
             // It should not contain anything
-            !aabb.contains(&p)
+            assert!(!aabb.contains(&p));
         }
-    }
 
-    // Test whether an `AABB` always contains its center.
-    quickcheck! {
-        fn test_aabb_contains_center(a: TupleVec, b: TupleVec) -> bool {
+        // Test whether an `AABB` always contains its center.
+        #[test]
+        fn test_aabb_contains_center(a: TupleVec, b: TupleVec) {
             // Define two points which will be the corners of the `AABB`
             let p1 = tuple_to_point(&a);
             let p2 = tuple_to_point(&b);
@@ -699,15 +700,14 @@ mod tests {
             let aabb = AABB::empty().grow(&p1).join_bounded(&p2);
 
             // Its center should be inside the `AABB`
-            aabb.contains(&aabb.center())
+            assert!(aabb.contains(&aabb.center()));
         }
-    }
 
-    // Test whether the joint of two point-sets contains all the points.
-    quickcheck! {
+        // Test whether the joint of two point-sets contains all the points.
+        #[test]
         fn test_join_two_aabbs(a: (TupleVec, TupleVec, TupleVec, TupleVec, TupleVec),
                                b: (TupleVec, TupleVec, TupleVec, TupleVec, TupleVec))
-                               -> bool {
+                               {
             // Define an array of ten points
             let points = [a.0, a.1, a.2, a.3, a.4, b.0, b.1, b.2, b.3, b.4];
 
@@ -716,32 +716,32 @@ mod tests {
 
             // Create two `AABB`s. One spanned the first five points,
             // the other by the last five points
-            let aabb1 = points.iter().take(5).fold(AABB::empty(), |aabb, point| aabb.grow(&point));
-            let aabb2 = points.iter().skip(5).fold(AABB::empty(), |aabb, point| aabb.grow(&point));
+            let aabb1 = points.iter().take(5).fold(AABB::empty(), |aabb, point| aabb.grow(point));
+            let aabb2 = points.iter().skip(5).fold(AABB::empty(), |aabb, point| aabb.grow(point));
 
             // The `AABB`s should contain the points by which they are spanned
             let aabb1_contains_init_five = points.iter()
                 .take(5)
-                .fold(true, |b, point| b && aabb1.contains(&point));
+                .all(|point| aabb1.contains(point));
             let aabb2_contains_last_five = points.iter()
                 .skip(5)
-                .fold(true, |b, point| b && aabb2.contains(&point));
+                .all(|point| aabb2.contains(point));
 
             // Build the joint of the two `AABB`s
             let aabbu = aabb1.join(&aabb2);
 
             // The joint should contain all points
             let aabbu_contains_all = points.iter()
-                .fold(true, |b, point| b && aabbu.contains(&point));
+                .all(|point| aabbu.contains(point));
 
             // Return the three properties
-            aabb1_contains_init_five && aabb2_contains_last_five && aabbu_contains_all
+            assert!(aabb1_contains_init_five && aabb2_contains_last_five && aabbu_contains_all);
         }
-    }
 
-    // Test whether some points relative to the center of an AABB are classified correctly.
-    quickcheck! {
-        fn test_points_relative_to_center_and_size(a: TupleVec, b: TupleVec) -> bool {
+        // Test whether some points relative to the center of an AABB are classified correctly.
+        // Currently doesn't test `approx_contains_eps` or `contains` very well due to scaling by 0.9 and 1.1.
+        #[test]
+        fn test_points_relative_to_center_and_size(a in tuplevec_large_strategy(), b in tuplevec_large_strategy()) {
             // Generate some nonempty AABB
             let aabb = AABB::empty()
                 .grow(&tuple_to_point(&a))
@@ -753,35 +753,31 @@ mod tests {
             let center = aabb.center();
 
             // Compute the min and the max corners of the AABB by hand
-            let inside_ppp = center + size_half;
-            let inside_mmm = center - size_half;
+            let inside_ppp = center + size_half * 0.9;
+            let inside_mmm = center - size_half * 0.9;
 
             // Generate two points which are outside the AABB
-            let outside_ppp = inside_ppp + Vector3::new(0.1, 0.1, 0.1);
-            let outside_mmm = inside_mmm - Vector3::new(0.1, 0.1, 0.1);
+            let outside_ppp = inside_ppp + size_half * 1.1;
+            let outside_mmm = inside_mmm - size_half * 1.1;
 
             assert!(aabb.approx_contains_eps(&inside_ppp, EPSILON));
             assert!(aabb.approx_contains_eps(&inside_mmm, EPSILON));
             assert!(!aabb.contains(&outside_ppp));
             assert!(!aabb.contains(&outside_mmm));
-
-            true
         }
-    }
 
-    // Test whether the surface of a nonempty AABB is always positive.
-    quickcheck! {
-        fn test_surface_always_positive(a: TupleVec, b: TupleVec) -> bool {
+        // Test whether the surface of a nonempty AABB is always positive.
+        #[test]
+        fn test_surface_always_positive(a: TupleVec, b: TupleVec) {
             let aabb = AABB::empty()
                 .grow(&tuple_to_point(&a))
                 .grow(&tuple_to_point(&b));
-            aabb.surface_area() >= 0.0
+            assert!(aabb.surface_area() >= 0.0);
         }
-    }
 
-    // Compute and compare the surface area of an AABB by hand.
-    quickcheck! {
-        fn test_surface_area_cube(pos: TupleVec, size: f32) -> bool {
+        // Compute and compare the surface area of an AABB by hand.
+        #[test]
+        fn test_surface_area_cube(pos: TupleVec, size in EPSILON..10e30_f32) {
             // Generate some non-empty AABB
             let pos = tuple_to_point(&pos);
             let size_vec = Vector3::new(size, size, size);
@@ -790,23 +786,21 @@ mod tests {
             // Check its surface area
             let area_a = aabb.surface_area();
             let area_b = 6.0 * size * size;
-            (1.0 - (area_a / area_b)).abs() < EPSILON
+            assert_float_eq!(area_a, area_b, rmax <= EPSILON);
         }
-    }
 
-    // Test whether the volume of a nonempty AABB is always positive.
-    quickcheck! {
-        fn test_volume_always_positive(a: TupleVec, b: TupleVec) -> bool {
+        // Test whether the volume of a nonempty AABB is always positive.
+        #[test]
+        fn test_volume_always_positive(a in tuplevec_large_strategy(), b in tuplevec_large_strategy()) {
             let aabb = AABB::empty()
                 .grow(&tuple_to_point(&a))
                 .grow(&tuple_to_point(&b));
-            aabb.volume() >= 0.0
+            assert!(aabb.volume() >= 0.0);
         }
-    }
 
-    // Compute and compare the volume of an AABB by hand.
-    quickcheck! {
-        fn test_volume_by_hand(pos: TupleVec, size: TupleVec) -> bool {
+        // Compute and compare the volume of an AABB by hand.
+        #[test]
+        fn test_volume_by_hand(pos in tuplevec_large_strategy(), size in tuplevec_large_strategy()) {
             // Generate some non-empty AABB
             let pos = tuple_to_point(&pos);
             let size = tuple_to_vector(&size);
@@ -815,13 +809,12 @@ mod tests {
             // Check its volume
             let volume_a = aabb.volume();
             let volume_b = (size.x * size.y * size.z).abs();
-            (1.0 - (volume_a / volume_b)).abs() < EPSILON
+            assert_float_eq!(volume_a, volume_b, rmax <= EPSILON);
         }
-    }
 
-    // Test whether generating an `AABB` from the min and max bounds yields the same `AABB`.
-    quickcheck! {
-        fn test_create_aabb_from_indexable(a: TupleVec, b: TupleVec, p: TupleVec) -> bool {
+        // Test whether generating an `AABB` from the min and max bounds yields the same `AABB`.
+        #[test]
+        fn test_create_aabb_from_indexable(a: TupleVec, b: TupleVec, p: TupleVec) {
             // Create a random point
             let point = tuple_to_point(&p);
 
@@ -834,7 +827,7 @@ mod tests {
             let aabb_by_index = AABB::with_bounds(aabb[0], aabb[1]);
 
             // The AABBs should be the same
-            aabb.contains(&point) == aabb_by_index.contains(&point)
+            assert!(aabb.contains(&point) == aabb_by_index.contains(&point));
         }
     }
 }
