@@ -12,7 +12,6 @@ use crate::utils::{concatenate_vectors, joint_aabb_of_shapes, Bucket};
 use crate::Point3;
 use crate::EPSILON;
 use std::f32;
-use std::iter::repeat;
 
 /// The [`BVHNode`] enum that describes a node in a [`BVH`].
 /// It's either a leaf node and references a shape (by holding its index)
@@ -24,6 +23,7 @@ use std::iter::repeat;
 /// [`BVH`]: struct.BVHNode.html
 ///
 #[derive(Debug, Copy, Clone)]
+#[cfg_attr(feature = "serde_impls", derive(serde::Serialize, serde::Deserialize))]
 #[allow(clippy::upper_case_acronyms)]
 pub enum BVHNode {
     /// Leaf node.
@@ -403,6 +403,8 @@ impl BVHNode {
 /// [`BVH`]: struct.BVH.html
 ///
 #[allow(clippy::upper_case_acronyms)]
+#[derive(Clone)]
+#[cfg_attr(feature = "serde_impls", derive(serde::Serialize, serde::Deserialize))]
 pub struct BVH {
     /// The list of nodes of the [`BVH`].
     ///
@@ -469,7 +471,7 @@ impl BVH {
                     child_r_aabb,
                     ..
                 } => {
-                    let padding: String = repeat(" ").take(depth as usize).collect();
+                    let padding: String = " ".repeat(depth as usize);
                     println!("{}child_l {}", padding, child_l_aabb);
                     print_node(nodes, child_l_index);
                     println!("{}child_r {}", padding, child_r_aabb);
@@ -478,7 +480,7 @@ impl BVH {
                 BVHNode::Leaf {
                     shape_index, depth, ..
                 } => {
-                    let padding: String = repeat(" ").take(depth as usize).collect();
+                    let padding: String = " ".repeat(depth as usize);
                     println!("{}shape\t{:?}", padding, shape_index);
                 }
             }
