@@ -559,10 +559,11 @@ mod tests {
     #[test]
     /// Test whether a simple update on a simple BVH yields the expected optimization result.
     fn test_optimize_simple_update() {
-        let mut shapes = Vec::new();
-        shapes.push(UnitBox::new(0, Point3::new(-50.0, 0.0, 0.0)));
-        shapes.push(UnitBox::new(1, Point3::new(-40.0, 0.0, 0.0)));
-        shapes.push(UnitBox::new(2, Point3::new(50.0, 0.0, 0.0)));
+        let mut shapes = vec![
+            UnitBox::new(0, Point3::new(-50.0, 0.0, 0.0)),
+            UnitBox::new(1, Point3::new(-40.0, 0.0, 0.0)),
+            UnitBox::new(2, Point3::new(50.0, 0.0, 0.0)),
+        ];
 
         let mut bvh = BVH::build(&mut shapes);
         bvh.pretty_print();
@@ -627,63 +628,62 @@ mod tests {
 
     /// Creates a small `BVH` with 4 shapes and 7 nodes.
     fn create_predictable_bvh() -> (Vec<UnitBox>, BVH) {
-        let mut shapes = Vec::new();
-        shapes.push(UnitBox::new(0, Point3::new(0.0, 0.0, 0.0)));
-        shapes.push(UnitBox::new(1, Point3::new(2.0, 0.0, 0.0)));
-        shapes.push(UnitBox::new(2, Point3::new(4.0, 0.0, 0.0)));
-        shapes.push(UnitBox::new(3, Point3::new(6.0, 0.0, 0.0)));
+        let shapes = vec![
+            UnitBox::new(0, Point3::new(0.0, 0.0, 0.0)),
+            UnitBox::new(1, Point3::new(2.0, 0.0, 0.0)),
+            UnitBox::new(2, Point3::new(4.0, 0.0, 0.0)),
+            UnitBox::new(3, Point3::new(6.0, 0.0, 0.0)),
+        ];
 
-        let mut nodes = Vec::new();
-
-        // Root node.
-        nodes.push(BVHNode::Node {
-            parent_index: 0,
-            depth: 0,
-            child_l_aabb: shapes[0].aabb().join(&shapes[1].aabb()),
-            child_l_index: 1,
-            child_r_aabb: shapes[2].aabb().join(&shapes[3].aabb()),
-            child_r_index: 2,
-        });
-
-        // Depth 1 nodes.
-        nodes.push(BVHNode::Node {
-            parent_index: 0,
-            depth: 1,
-            child_l_aabb: shapes[0].aabb(),
-            child_l_index: 3,
-            child_r_aabb: shapes[1].aabb(),
-            child_r_index: 4,
-        });
-        nodes.push(BVHNode::Node {
-            parent_index: 0,
-            depth: 1,
-            child_l_aabb: shapes[2].aabb(),
-            child_l_index: 5,
-            child_r_aabb: shapes[3].aabb(),
-            child_r_index: 6,
-        });
-
-        // Depth 2 nodes (leaves).
-        nodes.push(BVHNode::Leaf {
-            parent_index: 1,
-            depth: 2,
-            shape_index: 0,
-        });
-        nodes.push(BVHNode::Leaf {
-            parent_index: 1,
-            depth: 2,
-            shape_index: 1,
-        });
-        nodes.push(BVHNode::Leaf {
-            parent_index: 2,
-            depth: 2,
-            shape_index: 2,
-        });
-        nodes.push(BVHNode::Leaf {
-            parent_index: 2,
-            depth: 2,
-            shape_index: 3,
-        });
+        let nodes = vec![
+            // Root node.
+            BVHNode::Node {
+                parent_index: 0,
+                depth: 0,
+                child_l_aabb: shapes[0].aabb().join(&shapes[1].aabb()),
+                child_l_index: 1,
+                child_r_aabb: shapes[2].aabb().join(&shapes[3].aabb()),
+                child_r_index: 2,
+            },
+            // Depth 1 nodes.
+            BVHNode::Node {
+                parent_index: 0,
+                depth: 1,
+                child_l_aabb: shapes[0].aabb(),
+                child_l_index: 3,
+                child_r_aabb: shapes[1].aabb(),
+                child_r_index: 4,
+            },
+            BVHNode::Node {
+                parent_index: 0,
+                depth: 1,
+                child_l_aabb: shapes[2].aabb(),
+                child_l_index: 5,
+                child_r_aabb: shapes[3].aabb(),
+                child_r_index: 6,
+            },
+            // Depth 2 nodes (leaves).
+            BVHNode::Leaf {
+                parent_index: 1,
+                depth: 2,
+                shape_index: 0,
+            },
+            BVHNode::Leaf {
+                parent_index: 1,
+                depth: 2,
+                shape_index: 1,
+            },
+            BVHNode::Leaf {
+                parent_index: 2,
+                depth: 2,
+                shape_index: 2,
+            },
+            BVHNode::Leaf {
+                parent_index: 2,
+                depth: 2,
+                shape_index: 3,
+            },
+        ];
 
         (shapes, BVH { nodes })
     }
@@ -896,7 +896,7 @@ mod tests {
             .join(&shapes[3].aabb());
         assert!(nodes[0]
             .child_r_aabb()
-            .relative_eq(&right_subtree_aabb, EPSILON));
+            .relative_eq(right_subtree_aabb, EPSILON));
 
         assert!(nodes[2]
             .child_r_aabb()
@@ -1009,11 +1009,11 @@ mod bench {
 
         for _ in 0..iterations {
             let updated =
-                randomly_transform_scene(&mut triangles, num_move, &bounds, max_offset, &mut seed);
-            bvh.optimize(&updated, &triangles);
+                randomly_transform_scene(&mut triangles, num_move, bounds, max_offset, &mut seed);
+            bvh.optimize(&updated, triangles);
         }
 
-        intersect_bh(&bvh, &triangles, &bounds, b);
+        intersect_bh(&bvh, triangles, bounds, b);
     }
 
     #[bench]
@@ -1059,11 +1059,11 @@ mod bench {
         let num_move = (triangles.len() as f32 * percent) as usize;
         let mut seed = 0;
         for _ in 0..iterations {
-            randomly_transform_scene(&mut triangles, num_move, &bounds, max_offset, &mut seed);
+            randomly_transform_scene(&mut triangles, num_move, bounds, max_offset, &mut seed);
         }
 
         let bvh = BVH::build(&mut triangles);
-        intersect_bh(&bvh, &triangles, &bounds, b);
+        intersect_bh(&bvh, triangles, bounds, b);
     }
 
     #[bench]
