@@ -9,6 +9,7 @@ use crate::{Point3, Vector3};
 use num::{FromPrimitive, Integer};
 use obj::raw::object::Polygon;
 use obj::*;
+use proptest::prelude::*;
 use rand::rngs::StdRng;
 use rand::seq::SliceRandom;
 use rand::SeedableRng;
@@ -20,6 +21,27 @@ use crate::ray::Ray;
 /// A vector represented as a tuple
 pub type TupleVec = (f32, f32, f32);
 
+/// Generate a `TupleVec` for [`proptest::strategy::Strategy`] from -10e10 to 10e10
+/// A small enough range to prevent most fp32 errors from breaking certain tests
+/// Tests which rely on this strategy should probably be rewritten
+pub fn tuplevec_small_strategy() -> impl Strategy<Value = TupleVec> {
+    (
+        -10e10_f32..10e10_f32,
+        -10e10_f32..10e10_f32,
+        -10e10_f32..10e10_f32,
+    )
+}
+
+/// Generate a `TupleVec` for [`proptest::strategy::Strategy`] from -10e30 to 10e30
+/// A small enough range to prevent `f32::MAX` ranges from breaking certain tests
+pub fn tuplevec_large_strategy() -> impl Strategy<Value = TupleVec> {
+    (
+        -10e30_f32..10e30_f32,
+        -10e30_f32..10e30_f32,
+        -10e30_f32..10e30_f32,
+    )
+}
+
 /// Convert a `TupleVec` to a [`Point3`].
 pub fn tuple_to_point(tpl: &TupleVec) -> Point3 {
     Point3::new(tpl.0, tpl.1, tpl.2)
@@ -40,8 +62,8 @@ pub struct UnitBox {
 impl UnitBox {
     pub fn new(id: i32, pos: Point3) -> UnitBox {
         UnitBox {
-            id: id,
-            pos: pos,
+            id,
+            pos,
             node_index: 0,
         }
     }
@@ -89,7 +111,7 @@ pub fn build_some_bh<BH: BoundingHierarchy>() -> (Vec<UnitBox>, BH) {
 fn traverse_and_verify<BH: BoundingHierarchy>(
     ray_origin: Point3,
     ray_direction: Vector3,
-    all_shapes: &Vec<UnitBox>,
+    all_shapes: &[UnitBox],
     bh: &BH,
     expected_shapes: &HashSet<i32>,
 ) {
@@ -157,9 +179,9 @@ pub struct Triangle {
 impl Triangle {
     pub fn new(a: Point3, b: Point3, c: Point3) -> Triangle {
         Triangle {
-            a: a,
-            b: b,
-            c: c,
+            a,
+            b,
+            c,
             aabb: AABB::empty().grow(&a).grow(&b).grow(&c),
             node_index: 0,
         }
@@ -468,7 +490,7 @@ pub fn build_120k_triangles_bh<T: BoundingHierarchy>(b: &mut ::test::Bencher) {
 pub fn intersect_list(triangles: &[Triangle], bounds: &AABB, b: &mut ::test::Bencher) {
     let mut seed = 0;
     b.iter(|| {
-        let ray = create_ray(&mut seed, &bounds);
+        let ray = create_ray(&mut seed, bounds);
 
         // Iterate over the list of triangles.
         for triangle in triangles {
@@ -500,7 +522,7 @@ fn bench_intersect_sponza_list(b: &mut ::test::Bencher) {
 pub fn intersect_list_aabb(triangles: &[Triangle], bounds: &AABB, b: &mut ::test::Bencher) {
     let mut seed = 0;
     b.iter(|| {
-        let ray = create_ray(&mut seed, &bounds);
+        let ray = create_ray(&mut seed, bounds);
 
         // Iterate over the list of triangles.
         for triangle in triangles {
